from django.urls import path, include
from django.contrib.auth import views as auth_views
from django.views.generic.base import RedirectView
from django.conf import settings
from django.views.defaults import page_not_found, server_error

from . import views

app_name = 'uhepp_vault'
urlpatterns = [
    path('', views.home, name='home'),
    path('uhepp_v0_1.schema.json', RedirectView.as_view(url=settings.SCHEMA_URL_1)),
    path('uhepp_v0_2.schema.json', RedirectView.as_view(url=settings.SCHEMA_URL_2)),
    path('uhepp_v0_3.schema.json', RedirectView.as_view(url=settings.SCHEMA_URL_3)),
    path('uhepp_v0_4.schema.json', RedirectView.as_view(url=settings.SCHEMA_URL_4)),
    path('account/', views.AccountEditView.as_view(), name='account-detail'),
    path('login/', auth_views.LoginView.as_view()),
    path('logout/', views.logout, name='logout'),
    path('legal-notice/', views.legal_notice, name='legal-notice'),
    path('terms-of-service/', views.terms_of_service, name='terms-of-service'),
    path('privacy-policy/', views.privacy_policy, name='privacy-policy'),
    path('tokens/', views.TokenListView.as_view(), name='token-list'),
    path('tokens/new', views.TokenCreateView.as_view(), name='token-create'),
    path('tokens/<int:pk>', views.TokenDeleteView.as_view(), name='token-delete'),
    path('u/', views.UserListView.as_view(), name='user-list'),
    path('u/<str:username>/', views.UserDetailView.as_view(), name='user-detail'),
    path('c/', views.CollectionListView.as_view(), name='collection-list'),
    path('c/new', views.CollectionCreateView.as_view(), name='collection-create'),
    path('c/<str:pk>/', views.CollectionDetailView.as_view(), name='collection-detail'),
    path('c/<str:pk>/edit', views.CollectionUpdateView.as_view(), name='collection-update'),
    path('c/<str:pk>/delete', views.CollectionDeleteView.as_view(), name='collection-delete'),
    # path('p/', views.PlotListView.as_view(), name='plot-list'),
    path('p/<str:uuid>', views.PlotDetail.as_view(), name='plot-detail'),
    path('p/<str:uuid>/delete', views.PlotDeleteView.as_view(), name='plot-delete'),
    path('p/<str:uuid>/download', views.plot_download, name='plot-download'),
    path('p/<str:uuid>/preview', views.plot_preview, name='plot-preview'),
    path(r'404/', page_not_found, {'exception': Exception()}),
    path(r'500/', server_error),
]
